@@ -13,12 +13,12 @@ module RR
 
     include RR::DoubleDefinitions::DoubleDefinition::TimesDefinitionConstructionMethods
     include RR::DoubleDefinitions::DoubleDefinition::ArgumentDefinitionConstructionMethods
-  
+
     def ordered
       @ordered = true
       self
     end
-  
+
     def ordered?
       @ordered
     end
@@ -32,7 +32,15 @@ module RR
         call
       end
     end
-  
+
+    def subject_inspect
+      if subject.respond_to?(:__rr__original_inspect, true)
+        subject.__rr__original_inspect
+      else
+        subject.inspect
+      end
+    end
+
   protected
     attr_writer :times_matcher
 
@@ -40,9 +48,9 @@ module RR
       # with_no_args and with actually set @argument_expectation
       args.empty? ? with_no_args : with(*args)
     end
-  
+
     def install_method_callback(return_value_block)
       # Do nothing. This is to support DefinitionConstructionMethods
     end
   end
-end
\ No newline at end of file
+end
