@@ -24,5 +24,5 @@ RSpec.configure do |c|
   c.order = :random
 end
 
-Dir[ File.expand_path('../shared/*.rb', __FILE__) ].each {|fn| require fn }
-Dir[ File.expand_path('../support/**/*.rb', __FILE__) ].each {|fn| require fn }
+Dir[ File.expand_path('../shared/*.rb', __FILE__) ].sort.each {|fn| require fn }
+Dir[ File.expand_path('../support/**/*.rb', __FILE__) ].sort.each {|fn| require fn }
